@@ -1,19 +1,17 @@
 from __future__ import annotations
 
-import datetime
 from typing import TYPE_CHECKING, Any, Optional, Union
 
 from pydantic import Field
 
 from ..client.default import Default
 from ..types import (
-    ForceReply,
-    InlineKeyboardMarkup,
-    InputPollOption,
+    ChatIdUnion,
+    DateTimeUnion,
+    InputPollOptionUnion,
     Message,
     MessageEntity,
-    ReplyKeyboardMarkup,
-    ReplyKeyboardRemove,
+    ReplyMarkupUnion,
     ReplyParameters,
 )
 from .base import TelegramMethod
@@ -29,11 +27,11 @@ class SendPoll(TelegramMethod[Message]):
     __returning__ = Message
     __api_method__ = "sendPoll"
 
-    chat_id: Union[int, str]
+    chat_id: ChatIdUnion
     """Unique identifier for the target chat or username of the target channel (in the format :code:`@channelusername`)"""
     question: str
     """Poll question, 1-300 characters"""
-    options: list[Union[InputPollOption, str]]
+    options: list[InputPollOptionUnion]
     """A JSON-serialized list of 2-10 answer options"""
     business_connection_id: Optional[str] = None
     """Unique identifier of the business connection on behalf of which the message will be sent"""
@@ -59,7 +57,7 @@ class SendPoll(TelegramMethod[Message]):
     """A JSON-serialized list of special entities that appear in the poll explanation. It can be specified instead of *explanation_parse_mode*"""
     open_period: Optional[int] = None
     """Amount of time in seconds the poll will be active after creation, 5-600. Can't be used together with *close_date*."""
-    close_date: Optional[Union[datetime.datetime, datetime.timedelta, int]] = None
+    close_date: Optional[DateTimeUnion] = None
     """Point in time (Unix timestamp) when the poll will be automatically closed. Must be at least 5 and no more than 600 seconds in the future. Can't be used together with *open_period*."""
     is_closed: Optional[bool] = None
     """Pass :code:`True` if the poll needs to be immediately closed. This can be useful for poll preview."""
@@ -73,9 +71,7 @@ class SendPoll(TelegramMethod[Message]):
     """Unique identifier of the message effect to be added to the message; for private chats only"""
     reply_parameters: Optional[ReplyParameters] = None
     """Description of the message to reply to"""
-    reply_markup: Optional[
-        Union[InlineKeyboardMarkup, ReplyKeyboardMarkup, ReplyKeyboardRemove, ForceReply]
-    ] = None
+    reply_markup: Optional[ReplyMarkupUnion] = None
     """Additional interface options. A JSON-serialized object for an `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_, `custom reply keyboard <https://core.telegram.org/bots/features#keyboards>`_, instructions to remove a reply keyboard or to force a reply from the user"""
     allow_sending_without_reply: Optional[bool] = Field(
         None, json_schema_extra={"deprecated": True}
@@ -97,9 +93,9 @@ class SendPoll(TelegramMethod[Message]):
         def __init__(
             __pydantic__self__,
             *,
-            chat_id: Union[int, str],
+            chat_id: ChatIdUnion,
             question: str,
-            options: list[Union[InputPollOption, str]],
+            options: list[InputPollOptionUnion],
             business_connection_id: Optional[str] = None,
             message_thread_id: Optional[int] = None,
             question_parse_mode: Optional[Union[str, Default]] = Default("parse_mode"),
@@ -112,16 +108,14 @@ class SendPoll(TelegramMethod[Message]):
             explanation_parse_mode: Optional[Union[str, Default]] = Default("parse_mode"),
             explanation_entities: Optional[list[MessageEntity]] = None,
             open_period: Optional[int] = None,
-            close_date: Optional[Union[datetime.datetime, datetime.timedelta, int]] = None,
+            close_date: Optional[DateTimeUnion] = None,
             is_closed: Optional[bool] = None,
             disable_notification: Optional[bool] = None,
             protect_content: Optional[Union[bool, Default]] = Default("protect_content"),
             allow_paid_broadcast: Optional[bool] = None,
             message_effect_id: Optional[str] = None,
             reply_parameters: Optional[ReplyParameters] = None,
-            reply_markup: Optional[
-                Union[InlineKeyboardMarkup, ReplyKeyboardMarkup, ReplyKeyboardRemove, ForceReply]
-            ] = None,
+            reply_markup: Optional[ReplyMarkupUnion] = None,
             allow_sending_without_reply: Optional[bool] = None,
             reply_to_message_id: Optional[int] = None,
             **__pydantic_kwargs: Any,
